@@ -40,5 +40,5 @@ var languageNames = {
 "lt": "Lithuanian",
 "lv": "Latvian",
 "mk": "Macedonian",
-Binary file /chakra/desktop/libreoffice/src/libreoffice-6.4.0.3/helpcontent2/source/text/shared/help/browserhelp.xhp matches
+Binary file /builds/chakra/packages/desktop/libreoffice/src/libreoffice-6.4.1.2/helpcontent2/source/text/shared/help/browserhelp.xhp matches
 };
